==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fvkeyboard-0.4.tar.gz: vkeyboard/vkeyboard.js <==
//  vkeyboard main window.
//  Copyright 2003 Daniel K. Imori

//  This file is part of vkeyboard plugin.

//  vkeyboard plugin is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.

//  vkeyboard plugin is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.

//  You should have received a copy of the GNU General Public License
//  along with vkeyboard plugin; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function openwindow(passformname)
{
    win = window.open("", "", "toolbar=no,width=450,height=215");
    win.document.write("<HTML>\n<HEAD>\n<TITLE>Virtual Keyboard</TITLE>\n</H" +
    "EAD>\n<BODY>\n<SPAN id='msg'><B>Enter your password:</B></SPAN>\n<FORM " +
    "name='keyboard'>\n");
    n = Math.floor((126 - 33 + 1) * Math.random() + 33);
    for(i = 0; i <= 93; i++) {
        str = String.fromCharCode(n);
        if(n == 126) n = 32;
        if(n == 39) {
           win.document.write("<INPUT type='button' name='button" + i + "' v" +
           "alue=\"" + str + "\" style='width: 1.5em; border-style: none' on" +
           "click='window.opener.document.forms[0]." + passformname + ".valu" +
           "e += document.keyboard.button" + i + ".value; document.keyboard." +
           "close.focus()'>");
           n++;
           continue;
        }
        n++;
        win.document.write("<INPUT type='button' name='button" + i + "' valu" +
        "e='" + str + "' style='width: 1.5em; border-style: none' onclick='w" +
        "indow.opener.document.forms[0]." + passformname + ".value += docume" +
        "nt.keyboard.button" + i + ".value; document.keyboard.close.focus()'>");
    }
    win.document.write("<INPUT type='button' name='button" + i + "' value='" +
    ' ' + "' style='width: 1.5em; border-style: none' onclick='window.opener" +
    ".document.forms[0]." + passformname + ".value += document.keyboard.butt" +
    "on" + i + ".value; document.keyboard.close.focus()'>");
    win.document.write("<P><INPUT type='button' value='Clear' onclick='windo" +
    "w.opener.document.forms[0]." + passformname + ".value = \"\"'>&nbsp;<IN" +
    "PUT type='button' name='close' value='Close' onclick='self.close()'>\n<" +
    "/FORM>\n</BODY>\n</HTML>");
}

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fvkeyboard-0.5.tar.gz: vkeyboard/vkeyboard.js <==
//  vkeyboard main window.
//  Copyright 2003 Daniel K. Imori

//  This file is part of vkeyboard plugin.

//  vkeyboard plugin is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.

//  vkeyboard plugin is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.

//  You should have received a copy of the GNU General Public License
//  along with vkeyboard plugin; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function openwindow(passformname)
{
    win = window.open("", "", "toolbar=no,width=450,height=215");
    win.document.write("<HTML>\n<HEAD>\n<TITLE>Virtual Keyboard</TITLE>\n</H" +
    "EAD>\n<BODY>\n<SPAN id='msg'><B>Enter your password:</B></SPAN>\n<FORM " +
    "name='keyboard'>\n");
    n = Math.floor((126 - 32 + 1) * Math.random() + 32);  // first key
    for(i = 0; i <= 94; i++) {   // 95 keys
        str = String.fromCharCode(n);
        if(n == 126) n = 31;  // back to the first
        if(n == 39) {  // ' key
           win.document.write("<INPUT type='button' name='button" + i + "' v" +
           "alue=\"" + str + "\" style='width: 1.5em; border-style: none' on" +
           "click='window.opener.document.forms[0]." + passformname + ".valu" +
           "e += document.keyboard.button" + i + ".value; document.keyboard." +
           "login.focus()'>");
           n++;
           continue;
        }
        n++;
        win.document.write("<INPUT type='button' name='button" + i + "' valu" +
        "e='" + str + "' style='width: 1.5em; border-style: none' onclick='w" +
        "indow.opener.document.forms[0]." + passformname + ".value += docume" +
        "nt.keyboard.button" + i + ".value; document.keyboard.login.focus()'>");
    }
    win.document.write("<P><INPUT type='button' name='login' value='Login' o" +
    "nclick='window.opener.document.forms[0].submit(); self.close()'>&nbsp;&" +
    "nbsp;<INPUT type='button' value='Clear' onclick='window.opener.document" +
    ".forms[0]." + passformname + ".value = \"\"'>&nbsp;<INPUT type='button'" +
    " value='Close' onclick='self.close()'>\n</FORM>\n</BODY>\n</HTML>");
}
